Skip to contents

Date a tree using BactDating

Usage

runBactDating(tree, dates, rate = NA, keepRoot = F, ...)

Arguments

tree

Tree to date

dates

Dates of leaves in the tree

rate

If provided, force analysis to use specified value for rate

keepRoot

Whether to keep the root as in the input

...

Passed on to BactDating::bactdate

Value

resDating object containing results of BactDating analysis