Extract from BactDating output (r) the tree corresponding to a specific iteration in (w)
Source:R/dating.R
takeSample.RdExtract from BactDating output (r) the tree corresponding to a specific iteration in (w)
Usage
takeSample(r, w = nrow(r$record))