Skip to contents

Test to determine whether there are lineages with unbalanced dates For each node, perform a Kruskal-Wallis test for the dates on the left and on the right

Usage

testImbalance(tree, dates)

Arguments

tree

Tree to date

dates

Dates of leaves in the tree

Value

p-values