Usage
runDating(tree, dates, algo = "BactDating", rate = NA, keepRoot = F, ...)
Arguments
- tree
Tree to date
- dates
Dates of leaves in the tree
- algo
Algorithm to use, can be one of: LSD, node.dating, BactDating, treedater, TreeTime
- rate
If provided, force analysis to use specified value for rate
- keepRoot
Whether to keep the root as in the input
- ...
Passed on to dating algorithm
Value
resDating object containing results of dating analysis