Usage
runLSD(tree, dates, rate = NA, keepRoot = F, ...)
Arguments
- tree
Tree to date
- dates
Dates of leaves in the tree
- rate
If provided, force analysis to use specified value for rate
- keepRoot
Whether to keep the root as in the input
- ...
Ignored for the time being
Value
resDating object containing results of LSD analysis