Date a tree using node.dating
Usage
runNodeDating(tree, dates, rate = NA, keepRoot = F, ...)
Arguments
- tree
Tree to date
- dates
Dates of leaves in the tree
- rate
If provided, force analysis to use specified value for rate
- keepRoot
Whether to keep the root as in the input
- ...
Passed on to ape::node.dating
Value
resDating object containing results of node.dating analysis