R/simStructure.R
simStructure.Rd
Simulation with structure
simStructure( popStarts = c(2020, 2021, 2022), globalNeg = 1, NeFunPop, samplingDates )
Vector of dates when populations start
Value of Ne*g for the global population
Function determining the demographic trajectory of populations, default is CaveDive model with N=2 and h=0.2
A list containing for each population a vector of sampling dates
A simulated dated phylogeny