Test to determine whether there are lineages with unbalanced dates For each node, perform a Kruskal-Wallis test for the dates on the left and on the right
Source:R/testImbalance.R
testImbalance.RdTest to determine whether there are lineages with unbalanced dates For each node, perform a Kruskal-Wallis test for the dates on the left and on the right